@@ -2,7 +2,9 @@ import logging
 from IPython.display import display
 import ipywidgets as widgets
 import clease
-from clease_gui import BaseDashboard, register_logger, utils, update_statusbar
+from clease_gui.base_dashboard import BaseDashboard
+from clease_gui.status_bar import update_statusbar
+from clease_gui import register_logger, utils
 import clease_gui as gui
 
 from . import fitting_widgets
@@ -10,10 +12,7 @@ from . import fitting_widgets
 logger = logging.getLogger(__name__)
 register_logger(logger)
 
-# eval_logger = logging.getLogger('clease.evaluate')
-# register_logger(eval_logger)
-
-__all__ = ['ECIFitDashboard']
+__all__ = ["ECIFitDashboard"]
 
 
 class ECIFitDashboard(BaseDashboard):
@@ -23,15 +22,14 @@ class ECIFitDashboard(BaseDashboard):
 
         self.fitting_algo_dropdown = widgets.Dropdown(
             options=[
-                ('LASSO',
-                 fitting_widgets.LassoScheme(output=self.fitting_output)),
+                ("LASSO", fitting_widgets.LassoScheme(output=self.fitting_output)),
                 (
-                    'L2',
+                    "L2",
                     fitting_widgets.L2Scheme(output=self.fitting_output),
                 ),
                 # ('Genetic Algorithm', 'genetic_algorithm'),
             ],
-            description='Fitting Algorithm:',
+            description="Fitting Algorithm:",
             **self.DEFAULT_STYLE_KWARGS,
         )
         self.fitting_algo_dropdown.value.display()
@@ -48,8 +46,7 @@ class ECIFitDashboard(BaseDashboard):
         self.db_select_out = widgets.Output()
         self.db_select_widget = fitting_widgets.DBSelectWidget()
 
-        self.fit_eci_button = widgets.Button(description='Fit ECI',
-                                             button_style='primary')
+        self.fit_eci_button = widgets.Button(description="Fit ECI", button_style="primary")
         self.fit_eci_button.on_click(self._on_fit_eci_click)
 
     def display(self):
@@ -90,23 +87,22 @@ class ECIFitDashboard(BaseDashboard):
         # Get all parameters
         wdgt = self.fitting_algo_widget
         keys = list(wdgt.HYPERPARAMS)
-        if keys != ['alpha']:
-            raise NotImplementedError('Not yet implemented yet. Got keys:',
-                                      keys)
+        if keys != ["alpha"]:
+            raise NotImplementedError("Not yet implemented yet. Got keys:", keys)
 
-        alpha = wdgt.hyper_widget_dct['alpha']
+        alpha = wdgt.hyper_widget_dct["alpha"]
         is_opt = alpha.is_optimization
 
         evaluator = self._make_evaluator()
         scheme = wdgt.get_fitting_scheme()
         evaluator.set_fitting_scheme(fitting_scheme=scheme)
         if is_opt:
-            logger.info('Optimizing alpha')
+            logger.info("Optimizing alpha")
             min_val, max_val, step_val = alpha.get_min_max_step()
             spacing_type = alpha.get_spacing_type()
 
-            scale = 'log' if spacing_type == 'logspace' else 'linear'
-            logger.debug('Scale: %s', scale)
+            scale = "log" if spacing_type == "logspace" else "linear"
+            logger.debug("Scale: %s", scale)
             alphas, cv = evaluator.alpha_CV(
                 alpha_min=min_val,
                 alpha_max=max_val,
@@ -117,18 +113,17 @@ class ECIFitDashboard(BaseDashboard):
             ind = cv.argmin()
             alpha_val = alphas[ind]
             cv_min = cv[ind]
-            logger.info('Optimized alpha: %.3e, cv score: %.3e', alpha_val,
-                        cv_min)
+            logger.info("Optimized alpha: %.3e, cv score: %.3e", alpha_val, cv_min)
         else:
             alpha_val = alpha.get_float_value()
-        logger.info('Running fit with alpha: %.3e', alpha_val)
+        logger.info("Running fit with alpha: %.3e", alpha_val)
         # Even if we did an optimization, we want to fit at the optimized
         evaluator.set_fitting_scheme(fitting_scheme=scheme, alpha=alpha_val)
         evaluator.get_eci()
         self.set_evaluator(evaluator)
         eci = evaluator.get_eci_dict()
         self.set_eci(eci)
-        logger.info('Fitting complete.')
+        logger.info("Fitting complete.")
 
     def set_evaluator(self, evaluator):
         """The evaluator cannot be saved to file, so save it as private"""
@@ -137,12 +132,12 @@ class ECIFitDashboard(BaseDashboard):
         self.app_data[self.KEYS.EVALUATE] = evaluator
 
     @update_statusbar
-    @gui.utils.disable_cls_widget('fit_eci_button')
+    @gui.utils.disable_cls_widget("fit_eci_button")
     def _on_fit_eci_click(self, b):
-        try:
+        with self.event_context(logger=logger) as cm:
             self.fit_eci()
-        except Exception as exc:
-            self.log_error(logger, 'Failed to fit: %s', exc)
+        if not cm.success:
+            logger.warning("Failed to fit")
 
     def set_eci(self, value):
         self.app_data[self.KEYS.ECI] = value
@@ -152,5 +147,4 @@ class ECIFitDashboard(BaseDashboard):
         try:
             return self.app_data[self.KEYS.ECI]
         except KeyError:
-            raise ValueError(
-                'No ECI\'s present. Run fit first, or load ECI from file.')
+            raise ValueError("No ECI's present. Run fit first, or load ECI from file.")
