@@ -7,9 +7,12 @@ import ipywidgets as widgets
 import ase
 import ase.visualize
 import clease
-from clease_gui import BaseDashboard, register_logger, update_statusbar, utils, bool2symbol
+from clease_gui.base_dashboard import BaseDashboard
+from clease_gui.status_bar import update_statusbar
+from clease_gui.colors import bool2symbol
+from clease_gui import register_logger, utils
 
-__all__ = ['SupercellDashboard']
+__all__ = ["SupercellDashboard"]
 
 logger = logging.getLogger(__name__)
 register_logger(logger)
@@ -19,36 +22,35 @@ class SupercellDashboard(BaseDashboard):
     def initialize(self):
 
         self.sc_widgets = []
-        for coord in ('x', 'y', 'z'):
-            wdgt = widgets.BoundedIntText(description=f'Repetition ({coord}):',
-                                          value=5,
-                                          min=1,
-                                          max=999,
-                                          **self.DEFAULT_STYLE_KWARGS)
+        for coord in ("x", "y", "z"):
+            wdgt = widgets.BoundedIntText(
+                description=f"Repetition ({coord}):",
+                value=5,
+                min=1,
+                max=999,
+                **self.DEFAULT_STYLE_KWARGS,
+            )
             self.sc_widgets.append(wdgt)
 
         self.make_atoms_btn = widgets.Button(
-            description='Make random supercell',
-            layout=self.DEFAULT_BUTTON_LAYOUT)
+            description="Make random supercell", layout=self.DEFAULT_BUTTON_LAYOUT
+        )
         self.make_atoms_btn.on_click(self._on_make_supercell_click)
 
         self.desc_label = widgets.Label(value=self.make_desc_label())
 
-        self.view_atoms_btn = widgets.Button(
-            description='View Current Supercell',
-            layout=self.DEFAULT_BUTTON_LAYOUT)
-        self.view_atoms_btn.on_click(self._on_view_atoms_click)
+        self.view_atoms_btn = utils.make_clickable_button(
+            self._on_view_atoms_click,
+            description="View Current Supercell",
+            layout=self.DEFAULT_BUTTON_LAYOUT,
+        )
 
-        self.load_supercell_button = widgets.Button(
-            description='Load Supercell')
-        self.load_supercell_text = widgets.Text(description='Filename:',
-                                                value='supercell.traj')
+        self.load_supercell_button = widgets.Button(description="Load Supercell")
+        self.load_supercell_text = widgets.Text(description="Filename:", value="supercell.traj")
         self.load_supercell_button.on_click(self._on_load_supercell_click)
 
-        self.save_supercell_button = widgets.Button(
-            description='Save Supercell')
-        self.save_supercell_text = widgets.Text(description='Filename:',
-                                                value='supercell.traj')
+        self.save_supercell_button = widgets.Button(description="Save Supercell")
+        self.save_supercell_text = widgets.Text(description="Filename:", value="supercell.traj")
         self.save_supercell_button.on_click(self._on_save_supercell_click)
 
         self.species_output = widgets.Output()
@@ -58,15 +60,15 @@ class SupercellDashboard(BaseDashboard):
         display(self.desc_label)
         vbox_sc_widgets = widgets.VBox(children=self.sc_widgets)
 
-        hbox_buttons = widgets.HBox(children=[
-            self.make_atoms_btn,
-            self.view_atoms_btn,
-        ])
+        hbox_buttons = widgets.HBox(
+            children=[
+                self.make_atoms_btn,
+                self.view_atoms_btn,
+            ]
+        )
 
-        load_hbox = widgets.HBox(
-            children=[self.load_supercell_button, self.load_supercell_text])
-        save_hbox = widgets.HBox(
-            children=[self.save_supercell_button, self.save_supercell_text])
+        load_hbox = widgets.HBox(children=[self.load_supercell_button, self.load_supercell_text])
+        save_hbox = widgets.HBox(children=[self.save_supercell_button, self.save_supercell_text])
         display(save_hbox, load_hbox)
         display(hbox_buttons)
         display(vbox_sc_widgets)
@@ -76,31 +78,29 @@ class SupercellDashboard(BaseDashboard):
         try:
             supercell = self.supercell
         except ValueError:
-            return ''
+            return ""
         else:
             return supercell.get_chemical_formula()
 
     @update_statusbar
-    @utils.disable_cls_widget('load_supercell_button')
+    @utils.disable_cls_widget("load_supercell_button")
     def _on_load_supercell_click(self, b):
-        try:
+        with self.event_context(logger=logger):
             self.load_supercell()
-        except Exception as exc:
-            logger.error(exc)
 
     def load_supercell(self):
         fname = self.load_supercell_text.value
-        if fname == '':
-            raise ValueError('No filename supplied')
+        if fname == "":
+            raise ValueError("No filename supplied")
         cwd = self.app_data[self.KEYS.CWD]
         fname = cwd / fname
         self._load_supercell(fname)
 
     def _load_supercell(self, fname):
-        logger.info('Loading supercell from file: %s', fname)
+        logger.info("Loading supercell from file: %s", fname)
         atoms = ase.io.read(fname)
         self.set_supercell(atoms)
-        logger.info('Load successful.')
+        logger.info("Load successful.")
 
     def make_random_supercell(self):
         atoms = self.settings.prim_cell.copy()
@@ -113,22 +113,21 @@ class SupercellDashboard(BaseDashboard):
         self.set_supercell(supercell)
 
     @update_statusbar
-    @utils.disable_cls_widget('view_atoms_btn')
+    @utils.disable_cls_widget("view_atoms_btn")
     def _on_view_atoms_click(self, b):
-        try:
+        with self.event_context(logger=logger):
             self._visualize_supercell()
             self._update_desc_label()
-        except Exception as exc:
-            logger.error(exc)
 
     def _visualize_supercell(self):
         supercell = self.supercell
         if supercell is None:
-            raise ValueError('No supercell has been made yet.')
+            raise ValueError("No supercell has been made yet.")
         ase.visualize.view(supercell)
+        logger.info("Opened supercell in a new ASE GUI window.")
 
     def make_desc_label(self):
-        text = 'Create a supercell.'
+        text = "Create a supercell."
         try:
             sc = self.supercell
         except ValueError:
@@ -137,8 +136,8 @@ class SupercellDashboard(BaseDashboard):
         formula_unit = sc.get_chemical_formula()
         ntot = len(sc)
 
-        text += f' Current formula unit: {formula_unit}.'
-        text += f' Total number of atoms: {ntot}'
+        text += f" Current formula unit: {formula_unit}."
+        text += f" Total number of atoms: {ntot}"
 
         return text
 
@@ -158,21 +157,18 @@ class SupercellDashboard(BaseDashboard):
         try:
             return self.app_data[self.KEYS.SUPERCELL]
         except KeyError:
-            raise ValueError('No supercell available in app data.')
+            raise ValueError("No supercell available in app data.")
 
     @property
     def repetitions(self) -> Tuple[int]:
         return tuple(wdgt.value for wdgt in self.sc_widgets)
 
     @update_statusbar
-    @utils.disable_cls_widget('make_atoms_btn')
+    @utils.disable_cls_widget("make_atoms_btn")
     def _on_make_supercell_click(self, b):
-        try:
+        with self.event_context(logger=logger):
             self.make_random_supercell()
-            logger.info('Supercell created.')
-        except Exception as exc:
-            logger.error(exc)
-            return
+            logger.info("Supercell created.")
 
     def _get_new_struct_obj(self):
         """Helper function for creating a NewStructures object"""
@@ -184,29 +180,25 @@ class SupercellDashboard(BaseDashboard):
 
     def _make_atoms_at_conc(self, x):
         new_struct = self._get_new_struct_obj()
-        num_atoms_in_basis = [
-            len(indices) for indices in self.settings.index_by_basis
-        ]
+        num_atoms_in_basis = [len(indices) for indices in self.settings.index_by_basis]
         num_to_insert = self.concentration.conc_in_int(num_atoms_in_basis, x)
         return new_struct._random_struct_at_conc(num_to_insert)
 
     def save_supercell(self):
         supercell = self.supercell
         fname = self.save_supercell_text.value
-        if fname == '':
-            raise ValueError('No filename supplied.')
+        if fname == "":
+            raise ValueError("No filename supplied.")
         fname = self.app_data[self.KEYS.CWD] / fname
-        logger.info('Saving supercell to file: %s', fname)
+        logger.info("Saving supercell to file: %s", fname)
         ase.io.write(fname, supercell)
-        logger.info('Save successful.')
+        logger.info("Save successful.")
 
     @update_statusbar
-    @utils.disable_cls_widget('save_supercell_button')
+    @utils.disable_cls_widget("save_supercell_button")
     def _on_save_supercell_click(self, b):
-        try:
+        with self.event_context(logger=logger):
             self.save_supercell()
-        except Exception as exc:
-            logger.error(exc)
 
     def get_species_per_basis(self) -> List[Dict[str, int]]:
         settings = self.settings
@@ -221,8 +213,7 @@ class SupercellDashboard(BaseDashboard):
             species_per_basis.append(species)
         return species_per_basis
 
-    def set_supercell_species(self, species_per_basis: Sequence[Dict[str,
-                                                                     int]]):
+    def set_supercell_species(self, species_per_basis: Sequence[Dict[str, int]]):
         # Check that all species per basis add up to the correct number
         # by comparing to the current total
         basis_elements = self.settings.basis_elements
@@ -233,9 +224,10 @@ class SupercellDashboard(BaseDashboard):
             if cur_count != new_count:
                 sublatt = ii + 1
                 raise ValueError(
-                    ('Incorrect number of elements in sublattice {}.'
-                     ' Expected {}, but got {}.').format(
-                         sublatt, cur_count, new_count))
+                    (
+                        "Incorrect number of elements in sublattice {}." " Expected {}, but got {}."
+                    ).format(sublatt, cur_count, new_count)
+                )
         # Do the update, now we confirmed the counts are OK!
         atoms = self.supercell.copy()
         for ii, indices in enumerate(index_by_basis):
@@ -250,14 +242,14 @@ class SupercellDashboard(BaseDashboard):
             atoms.symbols[indices] = new_syms
         # We don't need to redraw the species output widgets again
         self.set_supercell(atoms, draw_species_output=False)
-        logger.info('Supercell updated.')
+        logger.info("Supercell updated.")
 
     def _make_species_output(self):
         out = self.species_output
 
         species_per_basis = self.get_species_per_basis()
 
-        update_supercell_btn = widgets.Button(description='Update supercell')
+        update_supercell_btn = widgets.Button(description="Update supercell")
 
         with out:
             clear_output(wait=True)
@@ -265,8 +257,7 @@ class SupercellDashboard(BaseDashboard):
             for ii, species_count in enumerate(species_per_basis):
                 sublattice_index = ii + 1
                 # Draw the sublattice boxes, and add the callback so we can get number of species
-                output, callback = make_sublattice_box(species_count,
-                                                       sublattice_index)
+                output, callback = make_sublattice_box(species_count, sublattice_index)
                 get_species_counts.append(callback)
                 display(output)
 
@@ -280,11 +271,9 @@ class SupercellDashboard(BaseDashboard):
             return count
 
         def on_update_click(b):
-            try:
-                with utils.disable_widget_context(update_supercell_btn):
+            with utils.disable_widget_context(update_supercell_btn):
+                with self.event_context(logger=logger):
                     self.set_supercell_species(make_species_per_basis())
-            except Exception as exc:
-                self.log_error(logger, exc)
 
         update_supercell_btn.on_click(on_update_click)
 
@@ -300,10 +289,10 @@ def make_sublattice_box(
     tot_in_basis = sum(species_count.values())
 
     # The output object in which the boxes are going to be drawn
-    sublattice_out = widgets.Output(layout={'border': '1px solid lightgray'})
+    sublattice_out = widgets.Output(layout={"border": "1px solid lightgray"})
 
     def make_make_label_text(is_ok=True):
-        s = f'Sublattice {sublattice_index}  {bool2symbol[is_ok]}'
+        s = f"Sublattice {sublattice_index}  {bool2symbol[is_ok]}"
         return f"<h1 style='font-size:17px'> {s} </h1>"
 
     label = widgets.HTML(value=make_make_label_text())
@@ -318,15 +307,19 @@ def make_sublattice_box(
     species_lst: List[str] = []
 
     # A box with the total count
-    tot_box = widgets.IntText(description='Total in basis:',
-                              value=tot_in_basis,
-                              disabled=True,
-                              style={'description_width': 'initial'})
+    tot_box = widgets.IntText(
+        description="Total in basis:",
+        value=tot_in_basis,
+        disabled=True,
+        style={"description_width": "initial"},
+    )
     # Box with the total specified number in this basis
-    tot_specified = widgets.IntText(description='Total specified:',
-                                    value=0,
-                                    disabled=True,
-                                    style={'description_width': 'initial'})
+    tot_specified = widgets.IntText(
+        description="Total specified:",
+        value=0,
+        disabled=True,
+        style={"description_width": "initial"},
+    )
     # Group the "total" boxes horizontally
     tot_hbox = widgets.HBox(children=[tot_box, tot_specified])
 
@@ -344,8 +337,7 @@ def make_sublattice_box(
     # Create the individual species boxes
     with sublattice_out:
         for species, count in species_count.items():
-            wdgt, ratio_wdgt = _make_species_boxes(species, count,
-                                                   tot_in_basis)
+            wdgt, ratio_wdgt = _make_species_boxes(species, count, tot_in_basis)
             # We need to update tot_specified if we make a change here
             wdgt.observe(observe_change)
             species_lst.append(species)
@@ -370,27 +362,25 @@ def make_sublattice_box(
         cur_count = sum(counts.values())
         if cur_count != tot_in_basis:
             raise ValueError(
-                ('Incorrect number of elements in sublattice {}.'
-                 ' Expected {}, but got {}.').format(sublattice_index,
-                                                     tot_in_basis, cur_count))
+                (
+                    "Incorrect number of elements in sublattice {}." " Expected {}, but got {}."
+                ).format(sublattice_index, tot_in_basis, cur_count)
+            )
         return counts
 
     return sublattice_out, get_counts
 
 
 def _make_species_boxes(
-        species: str, count: int,
-        tot_in_basis: int) -> Tuple[widgets.BoundedIntText, widgets.FloatText]:
+    species: str, count: int, tot_in_basis: int
+) -> Tuple[widgets.BoundedIntText, widgets.FloatText]:
     """Helper function to make the species count widget and the corresponding ratio box."""
     # The box in which the user types in the species count
-    wdgt = widgets.BoundedIntText(value=count,
-                                  min=0,
-                                  max=tot_in_basis,
-                                  description=f'{species}:')
+    wdgt = widgets.BoundedIntText(value=count, min=0, max=tot_in_basis, description=f"{species}:")
     # A box with the ratio of species this corresponds to
     ratio_wdgt = widgets.FloatText(
         value=count / tot_in_basis,
-        description='Ratio:',
+        description="Ratio:",
         disabled=True,
     )
 
